@@ -4,6 +4,8 @@
 set -e
 set -x
 
+QT_VERSION=6.6.1
+
 function build-static-qt-module() {
     local module=$1
     shift
@@ -12,17 +14,17 @@ function build-static-qt-module() {
     mkdir -p $STAGING_ROOT
     pushd $BUILD_ROOT
 
-    git clone --branch kde/5.15 --depth 1 https://invent.kde.org/qt/qt/$module
+    git clone --branch v$QT_VERSION --depth 1 https://invent.kde.org/qt/qt/$module
     cd $module
     mkdir build
     cd build
     if [ $module == "qtbase" ]; then
         ../configure -prefix $STAGING_ROOT $@
     else
-        $STAGING_ROOT/bin/qmake .. $@
+        cmake -DCMAKE_PREFIX_PATH=$STAGING_ROOT -DCMAKE_INSTALL_PREFIX=$STAGING_ROOT .. $@
     fi
     make -j 4
-    make install
+    make install/fast
 
     popd
 }
@@ -37,15 +39,13 @@ build-static-qt-module qtbase \
     -no-xcb -no-opengl -no-feature-vulkan \
     -no-feature-sql \
     -no-widgets \
-    -no-feature-network \
     -no-feature-sha3-fast \
     -no-accessibility \
     -no-feature-animation -no-feature-clipboard -no-feature-colornames -no-feature-cursor -no-feature-cssparser -no-feature-draganddrop \
     -no-feature-gestures -no-feature-im \
     -no-feature-image_heuristic_mask -no-feature-image_text -no-feature-imageformat_bmp -no-feature-imageformat_ppm -no-feature-imageformat_xbm -no-feature-imageformat_xpm -no-feature-imageformatplugin -no-feature-movie \
     -no-feature-picture -no-feature-pdf \
-    -no-feature-concurrent -no-feature-future -no-feature-sharedmemory -no-feature-systemsemaphore \
-    -no-feature-statemachine \
+    -no-feature-concurrent -no-feature-future -no-feature-sharedmemory \
     -no-feature-syntaxhighlighter \
     -no-feature-tabletevent -no-feature-wheelevent \
     -no-feature-texthtmlparser -no-feature-textodfwriter \
@@ -59,17 +59,16 @@ build-static-qt-module qtbase \
     -no-feature-textmarkdownreader -no-feature-textmarkdownwriter \
     -static -confirm-license -opensource -make libs -make tools
 
-build-static-qt-module qtdeclarative -- \
-    -no-feature-qml-debug \
-    -no-feature-qml-preview \
-    -no-feature-qml-profiler \
-    -no-feature-qml-animation \
-    -no-feature-qml-list-model \
-    -no-feature-qml-worker-script
+build-static-qt-module qtdeclarative \
+    -DFEATURE_qml_debug=OFF \
+    -DFEATURE_qml_preview=OFF \
+    -DFEATURE_qml_profiler=OFF \
+    -DFEATURE_qml_animation=OFF \
+    -DFEATURE_qml_delegate_model=OFF \
+    -DFEATURE_qml_network=OFF \
+    -DFEATURE_qml_list_model=OFF \
+    -DFEATURE_qml_worker_script=OFF \
 
-build-static-qt-module qttools
-
-# Patch .prl files to use static zlib
-for i in `find $STAGING_ROOT -name "*.prl"`; do
-    sed -i -e 's,-lz,/usr/lib64/libz.a,g' $i
-done
+build-static-qt-module qttools \
+    -DFEATURE_qtattributionsscanner=OFF \
+    -DFEATURE_qtplugininfo=OFF \
