@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KITINERARY_EVENT_H
-#define KITINERARY_EVENT_H
+#pragma once
 
 #include "kitinerary_export.h"
 #include "datatypes.h"
@@ -38,4 +37,3 @@ private:
 
 Q_DECLARE_METATYPE(KItinerary::Event)
 
-#endif // KITINERARY_EVENT_H
