@@ -144,6 +144,21 @@ static bool isEmptyJsonLdObject(const QJsonObject &obj)
     return true;
 }
 
+// cache timezones by IANA id, with Qt6 QTimeZone(QByteArray) is unreasonably slow
+// on Android, so that loading Itinerary's cached public transport data takes up to 20secs...
+// can and should be removed once this has been fixed in Qt
+static QTimeZone timeZone(const QByteArray &tzId)
+{
+    static QHash<QByteArray, QTimeZone> s_tzCache;
+    const auto it = s_tzCache.constFind(tzId);
+    if (it != s_tzCache.constEnd()) {
+        return it.value();
+    }
+    auto tz = QTimeZone(tzId);
+    s_tzCache.insert(tzId, tz);
+    return tz;
+}
+
 static QVariant propertyValue(const QMetaProperty &prop, const QJsonValue &v)
 {
     // enum handling must be done first, as prop.type() == Int
@@ -176,7 +191,7 @@ static QVariant propertyValue(const QMetaProperty &prop, const QJsonValue &v)
             const auto dtObj = v.toObject();
             if (dtObj.value(QLatin1String("@type")).toString() == QLatin1String("QDateTime")) {
                 dt = QDateTime::fromString(dtObj.value(QLatin1String("@value")).toString(), Qt::ISODate);
-                dt.setTimeZone(QTimeZone(dtObj.value(QLatin1String("timezone")).toString().toUtf8()));
+                dt.setTimeZone(timeZone(dtObj.value(QLatin1String("timezone")).toString().toUtf8()));
             }
         } else {
             auto str = v.toString();
@@ -189,7 +204,7 @@ static QVariant propertyValue(const QMetaProperty &prop, const QJsonValue &v)
             }
             // HACK QDateTimeParser handles 't' in the format but then forces it back to LocalTime in the end...
             if (dt.isValid() && dt.timeSpec() == Qt::LocalTime && str.endsWith(QLatin1Char('Z'))) {
-                dt = dt.toTimeSpec(Qt::UTC);
+                dt = dt.toTimeZone(QTimeZone::utc());
             }
             if (dt.isNull()) {
                 qCDebug(Log) << "Datetime parsing failed for" << str;
@@ -280,7 +295,7 @@ static QVariant createInstance(const QJsonObject& obj, const QString &type)
 
     if (type == QLatin1String("QDateTime")) {
         auto dt = QDateTime::fromString(obj.value(QLatin1String("@value")).toString(), Qt::ISODate);
-        dt.setTimeZone(QTimeZone(obj.value(QLatin1String("timezone")).toString().toUtf8()));
+        dt.setTimeZone(timeZone(obj.value(QLatin1String("timezone")).toString().toUtf8()));
         return dt;
     }
 
@@ -393,7 +408,7 @@ QJsonValue JsonLdDocument::toJsonValue(const QVariant &v)
         case QMetaType::QDateTime:
         {
             const auto dt = v.toDateTime();
-            if (dt.timeSpec() == Qt::TimeZone) {
+            if (dt.timeSpec() == Qt::TimeZone && dt.timeZone() != QTimeZone::utc()) {
                 QJsonObject dtObj;
                 dtObj.insert(QStringLiteral("@type"), QStringLiteral("QDateTime"));
                 dtObj.insert(QStringLiteral("@value"), dt.toString(Qt::ISODate));
